<?php
/**
 * lcp-stretch functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package lcp-stretch
 */

if ( ! function_exists( 'lcp_stretch_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function lcp_stretch_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on lcp-stretch, use a find and replace
		 * to change 'lcp-stretch' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'lcp-stretch', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu()
				register_nav_menus( array(
				'primary' => __( 'Main Navigation Menu', 'lcp-stretch' ),
		) );


		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'lcp_stretch_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'lcp_stretch_setup' );


//****Add short code for a widget
add_filter('widget_text', 'do_shortcode');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function lcp_stretch_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'lcp_stretch_content_width', 640 );
}
add_action( 'after_setup_theme', 'lcp_stretch_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function lcp_stretch_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Top Area One', 'lcp-stretch' ),
		'id'            => 'top-widget-one',
		'description'   => __( 'Add widgets here.', 'lcp-stretch' ),
		'before_widget' => '',
		'after_widget'  => '',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => __( 'Top Area Two', 'lcp-stretch' ),
		'id'            => 'top-widget-two',
		'description'   => __( 'Add widgets here.', 'lcp-stretch' ),
		'before_widget' => '',
		'after_widget'  => '',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => __( 'Top Area Three', 'lcp-stretch' ),
		'id'            => 'top-widget-three',
		'description'   => __( 'Add widgets here.', 'lcp-stretch' ),
		'before_widget' => '',
		'after_widget'  => '',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => __( 'Top Area Four', 'lcp-stretch' ),
		'id'            => 'top-widget-four',
		'description'   => __( 'Add widgets here.', 'lcp-stretch' ),
		'before_widget' => '',
		'after_widget'  => '',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer', 'lcp-stretch' ),
		'id'            => 'footer',
		'description'   => __( 'Add widgets here.', 'lcp-stretch' ),
		'before_widget' => '',
		'after_widget'  => '',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'lcp_stretch_widgets_init' );

/**
 * Add to the Customizer.
 */
function lcpstretch_customize_register( $wp_customize ) {
	/** Reorder the Customizer. **/
	$wp_customize->get_section('header_image')->priority = 80;
	$wp_customize->get_section('colors')->priority = 82;
	$wp_customize->get_section('background_image')->priority = 83;


	/*--------------------------------------------------------------
	Colors
	--------------------------------------------------------------*/
	/** Background Nav Bar **/
	$wp_customize->add_setting( 'bg_nav_bar' , array(
		'default'   => '#e6eeff',
		'transport' => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'bg_nav_bar', array(
		'label'      => esc_html__( 'Navigation Bar Background Color', 'lcp-stretch' ),
		'section'    => 'colors',
		'settings'   => 'bg_nav_bar',
	) ) );
	$wp_customize->get_setting( 'bg_nav_bar' )->transport = 'postMessage';

	/** Background Nav Button **/
	$wp_customize->add_setting( 'button_nav_bar' , array(
		'default'   => '#66b3ff',
		'transport' => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'button_nav_bar', array(
		'label'      => esc_html__( 'Navigation Button Color', 'lcp-stretch' ),
		'section'    => 'colors',
		'settings'   => 'button_nav_bar',
	) ) );

	/** Background Nav Button Hover Active **/
	$wp_customize->add_setting( 'button_hover_nav_bar' , array(
		'default'   => '#4d85ff',
		'transport' => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'button_hover_nav_bar', array(
		'label'      => esc_html__( 'Navigation Bar Hover/Active Button Color', 'lcp-stretch' ),
		'section'    => 'colors',
		'settings'   => 'button_hover_nav_bar',
	) ) );

	/** Font Nav Button color **/
	$wp_customize->add_setting( 'button_font_color_nav_bar' , array(
		'default'   => '#ffffff',
		'transport' => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'button_font_color_nav_bar', array(
		'label'      => esc_html__( 'Navigation Button Font Color', 'lcp-stretch' ),
		'section'    => 'colors',
		'settings'   => 'button_font_color_nav_bar',
	) ) );

	/** Font Nav Hover Active Button color **/
	$wp_customize->add_setting( 'button_font_color_hover_nav_bar' , array(
		'default'   => '#ffffff',
		'transport' => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'button_font_color_hover_nav_bar', array(
		'label'      => esc_html__( 'Navigation Button Hover/Active Font Color', 'lcp-stretch' ),
		'section'    => 'colors',
		'settings'   => 'button_font_color_hover_nav_bar',
	) ) );

	/** Widget Background Color **/
	$wp_customize->add_setting( 'bg_color_widgets' , array(
	    'default'   => '#e6eeff',
	    'transport' => 'postMessage',
	    'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'bg_color_widgets', array(
		'label'      => esc_html__( 'Widgets Background Color', 'lcp-stretch' ),
		'section'    => 'colors',
		'settings'   => 'bg_color_widgets',
	) ) );
	$wp_customize->get_setting( 'bg_color_widgets' )->transport = 'postMessage';

	/** Widget Font Color **/
	$wp_customize->add_setting( 'font_color_widgets' , array(
		'default'   => '#404040',
		'transport' => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'font_color_widgets', array(
		'label'      => esc_html__( 'Widgets Font Color', 'lcp-stretch' ),
		'section'    => 'colors',
		'settings'   => 'font_color_widgets',
	) ) );
	$wp_customize->get_setting( 'font_color_widgets' )->transport = 'postMessage';

	/** Main Content Area Background Color **/
	$wp_customize->add_setting( 'bg_color_main' , array(
		'default'   => '#f1f1f1',
		'transport' => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'bg_color_main', array(
		'label'      => esc_html__( 'Main Area Background Color', 'lcp-stretch' ),
		'section'    => 'colors',
		'settings'   => 'bg_color_main',
	) ) );
	$wp_customize->get_setting( 'bg_color_main' )->transport = 'postMessage';

	/** Main Content Area Font Color **/
	$wp_customize->add_setting( 'font_color_main' , array(
		'default'   => '#404040',
		'transport' => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'font_color_main', array(
		'label'      => esc_html__( 'Main Area Font Color', 'lcp-stretch' ),
		'section'    => 'colors',
		'settings'   => 'font_color_main',
	) ) );
	$wp_customize->get_setting( 'font_color_main' )->transport = 'postMessage';

	/** Footer Area Background Color **/
	$wp_customize->add_setting( 'bg_color_footer' , array(
		'default'   => '#e6eeff',
		'transport' => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'bg_color_footer', array(
		'label'      => esc_html__( 'Footer Background Color', 'lcp-stretch' ),
		'section'    => 'colors',
		'settings'   => 'bg_color_footer',
	) ) );
	$wp_customize->get_setting( 'bg_color_footer' )->transport = 'postMessage';

	/** Footer Area Font Color **/
	$wp_customize->add_setting( 'font_color_footer' , array(
		'default'   => '#404040',
		'transport' => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'font_color_footer', array(
		'label'      => esc_html__( 'Footer Font Color', 'lcp-stretch' ),
		'section'    => 'colors',
		'settings'   => 'font_color_footer',
	) ) );
	$wp_customize->get_setting( 'font_color_footer' )->transport = 'postMessage';

	/*--------------------------------------------------------------
		Widths
	--------------------------------------------------------------*/

	/** Top Area Widgets Width **/
	$wp_customize->add_section( 'lcp_stretch_width_section',
	   array(
		  'title' => esc_html__( 'Widths', 'lcp-stretch' ),
		  'capability' => 'edit_theme_options',
		  'priority'   => 84
	   )
	);
	$wp_customize->add_setting('top_area_widgets_width_settings',
		array(
			'default' => '90%',
			'transport' => 'postMessage',
			'sanitize_callback' => 'wp_filter_nohtml_kses',
		)
	);
	 $wp_customize->add_control('top_area_widgets_width_control',
		array(
			'label' => esc_html__( 'Top Area Widget Width in %', 'lcp-stretch' ),
			'description' => esc_html__( 'Example: 90%', 'lcp-stretch' ),
			'type' => 'option',
			'section' => 'lcp_stretch_width_section',
			'settings' => 'top_area_widgets_width_settings',
			'capability' => 'edit_theme_options',
	)
	);
	$wp_customize->get_setting( 'top_area_widgets_width_settings' )->transport = 'postMessage';

	$wp_customize->add_setting('content_area_width_settings',
		array(
			'default' => '75%',
			'transport' => 'postMessage',
			'sanitize_callback' => 'wp_filter_nohtml_kses',
		)
	);
	 $wp_customize->add_control('content_area_width_control',
		array(
			'label' => esc_html__( 'Main Content Area Width in %', 'lcp-stretch' ),
			'description' => esc_html( 'Example: 75%', 'lcp-stretch' ),
			'type' => 'option',
			'section' => 'lcp_stretch_width_section',
			'settings' => 'content_area_width_settings',
			'capability' => 'edit_theme_options',
	)
	);
	$wp_customize->get_setting( 'content_area_width_settings' )->transport = 'postMessage';

	/*--------------------------------------------------------------
	Number of Top Area Widgets
	--------------------------------------------------------------*/
	$wp_customize->add_section( 'top_area_widgets_settings',
	   array(
		  'title' => esc_html__( 'Number of Top Area Widgets', 'lcp-stretch' ),
		  'capability' => 'edit_theme_options',
		  'priority'   => 85,
	   )
	);
	$wp_customize->add_setting( 'top_widgets_num_radio',
	   array(
		  'default' => '0',
		  'transport' => 'refresh',
		  'sanitize_callback' => 'top_widgets_num_radio_sanitization',

	   )
	);
	$wp_customize->add_control( 'top_widgets_num_radio_control',
	   array(
		  'label' => esc_html__( 'Number of Top Area Widgets', 'lcp-stretch' ),
		  'section' => 'top_area_widgets_settings',
		  'priority' => 85,
		  'type' => 'radio',
		  'capability' => 'edit_theme_options',
		  'choices' => array(
			 '4' => esc_html__( '4', 'lcp-stretch' ),
			 '3' => esc_html__( '3', 'lcp-stretch' ),
			 '2' => esc_html__( '2', 'lcp-stretch' ),
			 '1' => esc_html__( '1', 'lcp-stretch' ),
			 '0' => esc_html__( '0', 'lcp-stretch' ),
		  ),
		  'settings' => 'top_widgets_num_radio'
	   )
	);
	function top_widgets_num_radio_sanitization( $input ) {
		$valid = array(
			'4' => '4',
			'3' => '3',
			'2' => '2',
			'1' => '1',
			'0' => '0',
		);

		if ( array_key_exists( $input, $valid ) ) {
			return $input;
		} else {
			return '';
		}
	}

	/*--------------------------------------------------------------
	Placement of Top Area Widgets
	--------------------------------------------------------------*/
	$wp_customize->add_section( 'top_area_placement_widgets_settings',
	   array(
		  'title' => esc_html__( 'Placement of Top Area Widgets' , 'lcp-stretch' ),
		  'capability' => 'edit_theme_options',
		  'priority'   => 86,
	   )
	);
	$wp_customize->add_setting( 'top_widgets_placement_radio',
	   array(
		  'default' => 'all',
		  'transport' => 'refresh',
		  'sanitize_callback' => 'top_widgets_placement_radio_sanitization',

	   )
	);
	$wp_customize->add_control( 'top_widgets_placement_radio_control',
	   array(
		  'label' => esc_html__( 'Placement of Top Area Widgets', 'lcp-stretch' ),
		  'section' => 'top_area_placement_widgets_settings',
		  'priority' => 86,
		  'type' => 'radio',
		  'capability' => 'edit_theme_options',
		  'choices' => array(
			 'all' => esc_html__( 'All Pages', 'lcp-stretch' ),
			 'home' => esc_html__( 'Homepage only', 'lcp-stretch' ),
		  ),
		  'settings' => 'top_widgets_placement_radio'
	   )
	);
	function top_widgets_placement_radio_sanitization ( $input ) {
		$valid = array(
			'all' => esc_html__( 'All Pages', 'lcp-stretch' ),
			'home' => esc_html__( 'Homepage only', 'lcp-stretch' ),
		);

		if ( array_key_exists( $input, $valid ) ) {
			return $input;
		} else {
			return '';
		}
	}


	/*--------------------------------------------------------------
	Mobile Header Image
	--------------------------------------------------------------*/
	$wp_customize->add_section( 'mobile_header_image_settings',
	array(
	  'title' => esc_html__( 'Mobile Header Image', 'lcp-stretch' ),
	  'capability' => 'edit_theme_options',
	  'priority'   => 81,
	)
	);
	$wp_customize->add_setting( 'img_upload_mobile',
	array(
	          'sanitize_callback' => 'mobile_header_sanitize_file'
	     )
    );

	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'img-upload',
			array(
				'label' => esc_html__('Image Upload','lcp-stretch' ),
				'section' => 'mobile_header_image_settings',
				'settings' => 'img_upload_mobile'
			)
		)
	);
	function mobile_header_sanitize_file( $file, $setting ) {
		//allowed file types
		$mimes = array(
			'jpg|jpeg|jpe' => 'image/jpeg',
			'gif'          => 'image/gif',
			'png'          => 'image/png'
		);

		//check file type from file name
		$file_ext = wp_check_filetype( $file, $mimes );

		//if file has a valid mime type return it, otherwise return default
		return ( $file_ext['ext'] ? $file : $setting->default );
	}
}
add_action( 'customize_register', 'lcpstretch_customize_register' );
function lcpstretch_customize_css()
{
    ?>
         <style type="text/css">
         	 .primary { background-color: <?php echo esc_attr(get_theme_mod('bg_nav_bar', '#e6eeff')); ?>; }
			 .primary a { background-color: <?php echo esc_attr(get_theme_mod('button_nav_bar', '#66b3ff')); ?>; }
			 .primary  li > a:focus { background-color: <?php echo esc_attr(get_theme_mod('button_hover_nav_bar', '#4d85ff')); ?>; }
			 .primary  ul ul :focus > a { background-color: <?php echo esc_attr(get_theme_mod('button_hover_nav_bar', '#4d85ff')); ?>; }
			 .primary  li:hover > a { background-color: <?php echo esc_attr(get_theme_mod('button_hover_nav_bar', '#4d85ff')); ?>; }
			 .primary  ul ul :hover > a { background-color: <?php echo esc_attr(get_theme_mod('button_hover_nav_bar', '#4d85ff')); ?>; }
			 .primary .current-menu-item > a { background-color: <?php echo esc_attr(get_theme_mod('button_hover_nav_bar', '#4d85ff')); ?>; }
			 .primary .current-menu-ancestor > a { background-color: <?php echo esc_attr(get_theme_mod('button_hover_nav_bar', '#4d85ff')); ?>; }
			 .primary a { color: <?php echo esc_attr(get_theme_mod('button_font_color_nav_bar', '#ffffff')); ?>; }
			 .primary  li > a:focus { color: <?php echo esc_attr(get_theme_mod('button_font_color_hover_nav_bar', '#ffffff')); ?>; }
			 .primary  ul ul :focus > a { color: <?php echo esc_attr(get_theme_mod('button_font_color_hover_nav_bar', '#ffffff')); ?>; }
			 .primary  li:hover > a { color: <?php echo esc_attr(get_theme_mod('button_font_color_hover_nav_bar', '#ffffff')); ?>; }
			 .primary  ul ul :hover > a { color: <?php echo esc_attr(get_theme_mod('button_font_color_hover_nav_bar', '#ffffff')); ?>; }
			 .primary .current-menu-item > a {color: <?php echo esc_attr(get_theme_mod('button_font_color_hover_nav_bar', '#ffffff')); ?>; }
			 .primary .current-menu-ancestor > a { color: <?php echo esc_attr(get_theme_mod('button_font_color_hover_nav_bar', '#ffffff')); ?>; }
			 .menu_main_tablet_button { background-color: <?php echo esc_attr(get_theme_mod('bg_nav_bar', '#e6eeff')); ?>; }
			 .bar1 { background: <?php echo esc_attr(get_theme_mod('button_nav_bar', '#4d85ff')); ?>; }
			 .bar2 { background: <?php echo esc_attr(get_theme_mod('button_nav_bar', '#4d85ff')); ?>; }
			 .bar3 { background: <?php echo esc_attr(get_theme_mod('button_nav_bar', '#4d85ff')); ?>; }
			 .primary_tablet a { color: <?php echo esc_attr(get_theme_mod('button_font_color_nav_bar', '#ffffff')); ?>; }
			 .primary_tablet a { background-color: <?php echo esc_attr(get_theme_mod('button_nav_bar', '#66b3ff')); ?>; }
			 .primary_tablet li { background-color: <?php echo esc_attr(get_theme_mod('button_nav_bar', '#66b3ff')); ?>; }
			 .primary_tablet .current-menu-item > a { background-color: <?php echo esc_attr(get_theme_mod('button_hover_nav_bar', '#4d85ff')); ?>; }
			 .primary_tablet .current-menu-ancestor > a { background-color: <?php echo esc_attr(get_theme_mod('button_hover_nav_bar', '#4d85ff')); ?>; }
			 .primary_tablet .current-menu-item > a { color: <?php echo esc_attr(get_theme_mod('button_font_color_hover_nav_bar', '#ffffff')); ?>; }
			 .primary_tablet .current-menu-ancestor > a { color: <?php echo esc_attr(get_theme_mod('button_font_color_hover_nav_bar', '#ffffff')); ?>; }
			 .button_phone_tablet_main_menu:after { color: <?php echo esc_attr(get_theme_mod('button_font_color_hover_nav_bar', '#ffffff')); ?>; }
			 .on_up:after  { color: <?php echo esc_attr(get_theme_mod('button_font_color_hover_nav_bar', '#ffffff')); ?>; }
			 .top-widget-area { width: <?php echo esc_attr(get_theme_mod('top_area_widgets_width_settings', '90%')); ?>; }
             .top_widget_one_optionOne, .top_widget_one_optionTwo, .top_widget_two_optionTwo, .top_widget_one_optionThree, .top_widget_two_optionThree,.top_widget_three_optionThree, .top_widget_one_optionFour, .top_widget_two_optionFour,
             .top_widget_three_optionFour, .top_widget_four_optionFour { background-color: <?php echo esc_attr(get_theme_mod('bg_color_widgets', '#e6eeff')); ?>; }
             .top_widget_one_optionOne, .top_widget_one_optionTwo, .top_widget_two_optionTwo, .top_widget_one_optionThree,
             .top_widget_two_optionThree, .top_widget_three_optionThree, .top_widget_one_optionFour, .top_widget_two_optionFour, .top_widget_three_optionFour, .top_widget_four_optionFour { color: <?php echo esc_attr(get_theme_mod('font_color_widgets', '#404040')); ?>; }
             .content-area { background-color: <?php echo esc_attr(get_theme_mod('bg_color_main', '#f1f1f1')); ?>; }
             .content-area { color: <?php echo esc_attr(get_theme_mod('font_color_main', '#404040')); ?>; }
             .site-content { width: <?php echo esc_attr(get_theme_mod('content_area_width_settings', '75%')); ?>; }
             .site-footer { background-color: <?php echo esc_attr(get_theme_mod('bg_color_footer', '#e6eeff')); ?>; }
             .site-footer { color: <?php echo esc_attr(get_theme_mod('font_color_footer', '#404040')); ?>; }
         </style>
    <?php
}
add_action( 'wp_head', 'lcpstretch_customize_css');

/**
 * Enqueue scripts and styles.
 */
function lcp_stretch_scripts() {
	wp_enqueue_style( 'lcp-stretch-style', get_stylesheet_uri() );

	wp_register_script( 'lcp-stretch_script', get_template_directory_uri() . '/js/lcp_stretch_menu.js', array( 'jquery' ) );
	wp_enqueue_script( 'lcp-stretch_script' );
	wp_enqueue_script( 'lcp-stretch-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'lcp_stretch_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}
/**
 * Default Header Image
 */
$default_url = get_template_directory_uri().'/header_image.jpg';
