<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package lcp-stretch
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="http://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'lcp-stretch' ); ?></a>

	<header id="masthead" class="site-header">
		<div class="outer_primary_tablet">
			<div class="menu_main_tablet_button">
				<div id = "main_menu_button"><div class="border_menu_main" onclick="lcp_menu_toggle_hamburger(this)">
				<div class="bar1"></div>
				<div class="bar2"></div>
				<div class="bar3"></div></div></div>
			</div>
			<nav class="menu_main_tablet" id = "id_menu_main_tablet">
				<?php wp_nav_menu( array('container_class' => 'primary_tablet', 'theme_location' => 'primary', 'fallback_cb'  => 'false' ) ); ?>
			</nav>
		</div>
		<div class = "lcp_clear_both"></div>
		<div class = "mobile-menu-gap"></div>
		<div class="site-branding">
			<?php
			the_custom_logo();
			if ( is_front_page() && is_home() ) :
				?>
				<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
				<?php
			else :
				?>
				<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
				<?php
			endif;
			$lcp_stretch_description = get_bloginfo( 'description', 'display' );
			if ( $lcp_stretch_description || is_customize_preview() ) :
				?>
				<p class="site-description"><?php echo $lcp_stretch_description; /* WPCS: xss ok. */ ?></p>
			<?php endif; ?>



			<div class = "header-desktop">
				<a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php the_header_image_tag(); ?></a>
			</div>
		</div><!-- .site-branding -->
		<?php $mobile_header_image = esc_url(get_theme_mod('img_upload_mobile')); ?>
		<div class="header-mobile">
			<?php if( esc_url(get_theme_mod('img_upload_mobile'))){?>
				<a href="<?php echo esc_url( home_url( '/' ) ); ?>"><img src = "<?php echo( $mobile_header_image ); ?>"></a>
				<?php
			}else{
				?><a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php the_header_image_tag(); ?></a><?php
			}
			?>
		</div><!-- .site-branding-mobile-->
		<div class="outer-primary">
			<nav class="menu_main" id = "id_menu_main">
				<?php wp_nav_menu( array( 'container_class' => 'primary', 'theme_location' => 'primary', 'fallback_cb'  => 'false' ) ); ?>
			</nav>
		</div>
		<div class = "lcp_clear_both"></div>
	</header><!-- #masthead -->
<?php $num_top_area_widgets = esc_attr(get_theme_mod('top_widgets_num_radio', '0')); ?>
<?php $placement_top_area_widgets = esc_attr(get_theme_mod('top_widgets_placement_radio', 'all')); ?>
<?php

if ((is_front_page() ) && ($placement_top_area_widgets === "home")  ){
	fnc_placement_top_area_widgets($num_top_area_widgets);
}
if ($placement_top_area_widgets === "all") {
	fnc_placement_top_area_widgets($num_top_area_widgets);
}

function fnc_placement_top_area_widgets($num_top_area_widgets) {
	if ($num_top_area_widgets === "1"){
		?>
		<div class = "top-widget-area flex-lcp" id = "id_top-widget-area">
			<div class = "top_widget_one_optionOne">
				<?php dynamic_sidebar( 'top-widget-one' ); ?>
			</div>
		</div>
		<?php
	}
	if ($num_top_area_widgets === "2"){
		?>
		<div class = "top-widget-area flex-lcp" id = "id_top-widget-area">
			<div class = "top_widget_one_optionTwo">
				<?php dynamic_sidebar( 'top-widget-one' ); ?>
			</div>
			<div class = "top_widget_two_optionTwo">
				<?php dynamic_sidebar( 'top-widget-two' ); ?>
			</div>
		</div>
		<?php
	}
	if ($num_top_area_widgets === "3"){
		?>
		<div class = "top-widget-area flex-lcp" id = "id_top-widget-area">
			<div class = "top_widget_one_optionThree">
				<?php dynamic_sidebar( 'top-widget-one' ); ?>
			</div>
			<div class = "top_widget_two_optionThree">
				<?php dynamic_sidebar( 'top-widget-two' ); ?>
			</div>
			<div class = "top_widget_three_optionThree">
				<?php dynamic_sidebar( 'top-widget-three' ); ?>
			</div>
		</div>
		<?php
	}
	if ($num_top_area_widgets === "4"){
		?>
		<div class = "top-widget-area flex-lcp" id = "id_top-widget-area">
			<div class = "top_widget_one_optionFour">
				<?php dynamic_sidebar( 'top-widget-one' ); ?>
			</div>
			<div class = "top_widget_two_optionFour">
				<?php dynamic_sidebar( 'top-widget-two' ); ?>
			</div>
			<div class = "top_widget_three_optionFour">
				<?php dynamic_sidebar( 'top-widget-three' ); ?>
			</div>
			<div class = "top_widget_four_optionFour">
				<?php dynamic_sidebar( 'top-widget-four' ); ?>
			</div>
		</div>
		<?php
	}
}

	?>


	<div id="content" class="site-content">
